@@ -66,10 +66,21 @@ drawSpecPPM <- function(Y.spec, X.ppm, LeftIndex = -1, RightIndex = -1, groupFac
         Y.spec <- as.matrix(Y.spec)
     }
     
+    if (any(is.na(X.ppm))) {
+        warning("X.ppm contains NA's, trying to remove these.")
+        Y.spec <- Y.spec[,!is.na(X.ppm)]
+        X.ppm <- X.ppm[!is.na(X.ppm)]
+    }
+    if(any(is.na(Y.spec))){
+        stop("Y.spec contains NA's. Don't know how to deal with these.")
+    }
+    
     groupFactor_name <- groupFactor
     
     if (X.ppm[1] < X.ppm[2]) {
-        stop("The whole point of this function is to plot with an inverted axis (specific for NMR spectroscopy). X.ppm is not inverted.")
+        message("X.ppm is not inverted. Inverting X.ppm and Y.spec")
+        Y.spec <- Y.spec[,order(X.ppm, decreasing = T)]
+        X.ppm <- rev(X.ppm)
     }
     
     
@@ -96,13 +107,13 @@ drawSpecPPM <- function(Y.spec, X.ppm, LeftIndex = -1, RightIndex = -1, groupFac
     }
     
     if (maxHeight != -1) {
-        for (i in 1:nrow(Y.spec)) {
+        for (i in seq_len(nrow(Y.spec))) {
             myIndex <- which(Y.spec[i, ] > maxHeight)
             Y.spec[i, myIndex] <- maxHeight
         }
     }
     if (minHeight != -1) {
-        for (i in 1:nrow(Y.spec)) {
+        for (i in seq_len(nrow(Y.spec))) {
             myIndex <- which(Y.spec[i, ] < minHeight)
             Y.spec[i, myIndex] <- minHeight
         }
@@ -165,7 +176,7 @@ drawSpecPPM <- function(Y.spec, X.ppm, LeftIndex = -1, RightIndex = -1, groupFac
         xPos.user <- NULL
         if (!"numeric" %in% class(ticks)) 
             ticks <- as.numeric(as.character(ticks))
-        for (tk in 1:length(ticks)) {
+        for (tk in seq_along(ticks)) {
             xPos.user[tk] <- which(abs(X.ppm - ticks[tk]) == min(abs(X.ppm - ticks[tk])))[1]
             if (min(abs(X.ppm - ticks[tk])) > min(abs(diff(ticks)))) 
                 stop(paste("tickmark", as.character(ticks[tk]), "is not close to any value in the provided ppm vector"))
@@ -190,7 +201,7 @@ drawSpecPPM <- function(Y.spec, X.ppm, LeftIndex = -1, RightIndex = -1, groupFac
         ppm.ticks <- seq(left.tick.ppm, right.tick.ppm, -ppm.tickwidth)
         ppm.mindiff <- min(abs(diff(ppm.ticks)))
         xPos.auto <- NULL
-        for (tk in 1:length(ppm.ticks)) {
+        for (tk in seq_along(ppm.ticks)) {
             xPos.auto[tk] <- which(abs(X.ppm.sub - ppm.ticks[tk]) == min(abs(X.ppm.sub - ppm.ticks[tk])))[1]
             if (min(abs(X.ppm.sub - ppm.ticks[tk])) > ppm.mindiff/5) {
                 xPos.auto[tk] <- NA
@@ -214,7 +225,7 @@ drawSpecPPM <- function(Y.spec, X.ppm, LeftIndex = -1, RightIndex = -1, groupFac
     
     for (i in 1:length(levels(groupFactor))) {
         groupFactorIdx <- which(groupFactor == levels(groupFactor)[i])
-        for (j in 1:length(groupFactorIdx)) {
+        for (j in seq_along(groupFactorIdx)) {
             graphics::lines(yn[groupFactorIdx[j], ], col = plotcols[i], lwd = lwd)
         }
     }
